@@ -267,7 +267,7 @@ class PdbxLoaderWorker(object):
 
     def __writePathList(self, filePath, pathList):
         try:
-            with open(filePath, "w") as ofh:
+            with open(filePath, "w", encoding="utf-8") as ofh:
                 for pth in pathList:
                     ofh.write("%s\n" % pth)
             return True
@@ -510,6 +510,7 @@ class PdbxLoader(object):
         self.__chunkSize = max(chunkSize, 1)
         #
         self.__cfgOb = cfgOb
+        self.__cfgSectionName = self.__cfgOb.getDefaultSectionName()
         self.__resourceName = resourceName
         #
         self.__readBackCheck = readBackCheck
@@ -518,12 +519,13 @@ class PdbxLoader(object):
         self.__rebuildSchemaFlag = rebuildSchemaFlag
         self.__mpFormat = "[%(levelname)s] %(asctime)s %(processName)s-%(module)s.%(funcName)s: %(message)s"
         #
+        #
         self.__schP = SchemaProvider(self.__cfgOb, self.__cachePath, useCache=self.__useSchemaCache, rebuildFlag=self.__rebuildSchemaFlag)
         self.__rpP = RepositoryProvider(cfgOb=self.__cfgOb, numProc=self.__numProc, fileLimit=self.__fileLimit, cachePath=self.__cachePath)
         #
         self.__statusList = []
         #
-        self.__sectionName = "site_info_configuration"
+
         self.__dmh = None
         #
 
@@ -583,7 +585,7 @@ class PdbxLoader(object):
             logger.info("Beginning load operation (%r) for database %s", loadType, databaseName)
             startTime = self.__begin(message="loading operation")
             #
-            modulePathMap = self.__cfgOb.get("DICT_METHOD_HELPER_MODULE_PATH_MAP", sectionName=self.__sectionName)
+            modulePathMap = self.__cfgOb.get("DICT_METHOD_HELPER_MODULE_PATH_MAP", sectionName=self.__cfgSectionName)
             dP = DictionaryApiProviderWrapper(self.__cachePath, cfgOb=self.__cfgOb, useCache=True)
             dictApi = dP.getApiByName(databaseName)
             # ---
@@ -668,13 +670,21 @@ class PdbxLoader(object):
                 subLists = [locatorObjList]
             #
             if subLists:
-                logger.info("Starting load of %s (%r) using numProc %d outer subtask count %d subtask length %d", databaseName, loadType, numProc, len(subLists), len(subLists[0]))
+                logger.info(
+                    "Starting load of %s (%r) using %d processor for total count %d outer subtask count %d subtask length %d",
+                    databaseName,
+                    loadType,
+                    numProc,
+                    numPaths,
+                    len(subLists),
+                    len(subLists[0]),
+                )
             else:
                 logger.error("Path partitioning fails for %s (%r) using numProc %d", databaseName, loadType, numProc)
             #
             failList = []
             for ii, subList in enumerate(subLists):
-                logger.info("Running outer subtask %d of %d length %d", ii + 1, len(subLists), len(subList))
+                logger.info("Starting outer subtask %d of %d length %d", ii + 1, len(subLists), len(subList))
                 #
                 # pdbxLoaderWorker = PdbxLoaderWorker(self.__cfgOb, self.__rpP, self.__dmh, self.__resourceName)
                 mpu = MultiProcUtil(verbose=True)
@@ -682,10 +692,11 @@ class PdbxLoader(object):
                 mpu.setOptions(optionsD=optD)
                 mpu.set(workerObj=self, workerMethod="loadWorker")
                 ok, failListT, _, _ = mpu.runMulti(dataList=subList, numProc=numProc, numResults=1, chunkSize=chunkSize)
-                logger.info("Completed outer subtask %d of %d length %d with failure count %d status %r", ii + 1, len(subLists), len(subList), len(failListT), ok)
+                logger.info("Completed outer subtask %d of %d (status=%r) length %d failures (%d) %r", ii + 1, len(subLists), ok, len(subList), len(failListT), failListT)
                 failList.extend(failListT)
             failList = list(set(failList))
-            logger.debug("Failing path list %r", failList)
+            if failList:
+                logger.info("Full failed path list %r", failList)
             #
             failedPathList = self.__rpP.getLocatorPaths(failList, locatorIndex=0)
             if failedFilePath and failedPathList:
@@ -1043,7 +1054,7 @@ class PdbxLoader(object):
 
     def __writePathList(self, filePath, pathList):
         try:
-            with open(filePath, "w") as ofh:
+            with open(filePath, "w", encoding="utf-8") as ofh:
                 for pth in pathList:
                     ofh.write("%s\n" % pth)
             return True
